.. sklearn_utils documentation master file, created by
   sphinx-quickstart on Tue Nov 28 10:27:45 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../README.md

API Documentation
==================


Analysis
-----------
		   
.. automodule:: metabolitics.analysis
                :members:
                :undoc-members:
                :show-inheritance:

Preprocessing
--------------
		   
.. automodule:: metabolitics.preprocessing
                :members:
                :undoc-members:
                :show-inheritance:

Utils
-----------
		   
.. automodule:: metabolitics.utils
                :members:
                :undoc-members:
                :show-inheritance:
		   
Extensions
-----------

.. automodule:: metabolitics.extensions
                :members:
                :undoc-members:
                :show-inheritance:

